#
# spec file for package ghc-codo-notation
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name codo-notation
Name:           ghc-%{pkg_name}
Version:        0.5.2
Release:        lp150.1.7
Summary:        A notation for comonads, analogous to the do-notation for monads
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-haskell-src-meta-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-uniplate-devel

%description
A notation for comonads, analogous to the do-notation for monads.

Requires the 'TemplateHaskell' and 'QuasiQuotes' extensions.

Example 1:

' &#x7b;-# LANGUAGE TemplateHaskell #-&#x7d; &#x7b;-# LANGUAGE QuasiQuotes
#-&#x7d;

import Control.Comonad import Language.Haskell.Codo

foo :: (Comonad c, Num a) => c a -> a foo = [codo| x => extract x + 1 |] '

Example 2:

' import Data.Monoid instance Monoid Double where &#x20;&#x20;&#x20; mempty =
0.0 &#x20;&#x20;&#x20; mappend = (+)

differentiate f = ((f 0.001) - f 0) / 0.001

minima :: (Double -> Double) -> Bool minima = [codo| f => f' <- differentiate f
&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;
f'' <- differentiate f'
&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;&#x20;
(extract f' &#60; 0.001) && (extract f'' &#62; 0) |] '

Further explanation of the syntax can be found in the following (short) paper:
<http://www.cl.cam.ac.uk/~dao29/drafts/codo-notation-orchard-ifl12.pdf> with a
numer of examples.

Further examples can be found here:
<https://github.com/dorchard/codo-notation>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.5.2 revision 0 with cabal2obs.
